#!/public/bin/perl -w

##############################################################################
# Filename: formatHouseData.pl
# Version:  1.001
# Author:   Tom Kralidis
# Date:     29/01/00
# Project:  GEOHome v1.0
# Purpose:  Extracts data from input house text files into tab-delimited
#           text file, for import to GEOHome component.
# Language: Perl
# Modules:  None
# Usage:    formatHouseData.pl in desired input data directory
# Misc:     Consult technical documentation for specifications / requirements
#
# Change log:
#
# Author        Date           Changes
# T. Kralidis   14-Jan-2000    Initial Implementation.
#
##############################################################################

# declare variables

$fileCount = 0;
$. = 0;

# open and write fields to output text file

open(CDT, ">maison.txt") || die "Yikes0: $!\n";
print CDT "mls_id,price,type,area,numBeds,numBaths,hotLink\n";

# open current directory and list house data to be processed

opendir(THISDIR, ".") || die "Yikes1: $!\n";
@houseFiles = sort grep(/^\d{6}\.txt$/, readdir(THISDIR));
closedir(THISDIR);

# loop through files, extracting data needed

foreach(@houseFiles)
{
  open(FILE, "$_") or die "YikesFilePeruseLoop:  $!\n";

  # extract data

  do { $mlsnum = <FILE> } until $. == 3 || eof;
  do { $price = <FILE> } until $. == 4 || eof;
  do { $type  = <FILE> } until $. == 5 || eof;
  do { $area  = <FILE> } until $. == 6 || eof;
  do { $beds  = <FILE> } until $. == 7 || eof;
  do { $baths  = <FILE> } until $. == 8 || eof;

  # remove null padding

  $mlsnum = $1 if $mlsnum =~ /\#\:\s(\d+)/;
  $price = $1 . $2 if $price =~ /\$(\d+)\,(\d{3})/;
  $type = $1 if $type =~ /Image\]\s(.*)$/;
  $area = $1 if $area =~ /Image\]\s(\w+)/;
  $beds = $1 if $beds =~ /(\d)/;
  $baths = $1 if $baths =~ /(\d)/;
  
  # print to output filehandle

  $hotlink = "http\:\/\/www\.nrcan\.gc\.ca\/\~tkralidi\/cgi\-bin\/findhouse\.cgi\?$mlsnum";

  print CDT "$mlsnum,$price,$type,$area,$beds,$baths,$hotlink\n";

  close(FILE);
  $fileCount++;
}

close(CDT);

print "$fileCount files processed.\nDone\n";

exit(0);
